@@ -7,6 +7,7 @@ filters if needed
 import subprocess
 import argparse
 import sys
+import numpy as np
 from cyvcf2 import VCF
 from cyvcf2 import Writer
 from tqdm import tqdm
@@ -32,9 +33,11 @@ def arg_parser():
         action='store_true', help='Remove heterozygote calls [optional]')
     parser.add_argument('--min_GQ', required=False, default=30,
         type=int, help='Min GQ at both sites (default 30)')
+    parser.add_argument('--purity_filter', required=False, default=1,
+        type=int, help='Purity filter stringency (default 1 read allowed) - set -1 to disable')
     parser.add_argument('-o', '--out', required=True,
         type=str, help='File to write to. If .gz, script will bgzip and tabix file.')
-    parser.add_argument('--version', action='version', version='readcomb 0.1.3')
+    parser.add_argument('--version', action='version', version='readcomb 0.1.5')
 
     return parser
 
@@ -68,6 +71,8 @@ def vcfprep(args):
 
     if args.out.endswith('.gz'):
         outfile = args.out.replace('.gz', '')
+    else:
+        outfile = args.out
     vcf_out = Writer(outfile, vcf_in)
     vcf_out.write_header()
 
@@ -96,22 +101,34 @@ def vcfprep(args):
             continue
 
         # ensure parental alleles differ
-        if record.gt_bases[0] == record.gt_bases[1]:
+        if record.gt_bases[0][0] == record.gt_bases[1][0]:
             continue
 
+        # purity filter
+        purity_threshold = args.purity_filter
+        if not purity_threshold == -1:
+            # allow at most [threshold] read with opposite parent allele by default
+            if len(record.ALT) == 1:
+                if min(record.gt_depths - record.gt_alt_depths) > purity_threshold:
+                    continue
+                if min(record.gt_depths - record.gt_ref_depths) > purity_threshold:
+                    continue
+            elif len(record.ALT) > 1:
+                # need to get allele-specific depths from raw record
+                depths = [call.split(':')[1].split(',') for call in record.__str__().split('\t')[-2:]]
+                # only keep depths for non-ref alleles
+                call1_depths = np.array(depths[0][1:], dtype='int')
+                call2_depths = np.array(depths[1][1:], dtype='int')
+                # depth for opposite alt allele should be no more than [threshold]
+                if min(call1_depths) > threshold:
+                    continue
+                if min(call2_depths) > threshold:
+                    continue
+
         # remove any calls with deleted alleles
         if '*' in ' '.join(record.gt_bases):
             continue
 
-        # remove uninformative indels
-        # e.g. A/ATC - either both match, or we have a no match
-        if not args.snps_only:
-            if record.is_indel:
-                allele_1 = record.gt_bases[0].split('/')[0].split('|')[0]
-                allele_2 = record.gt_bases[1].split('/')[0].split('|')[0]
-                if allele_1 in allele_2 or allele_2 in allele_1:
-                    continue
-
         # only passes if record not caught in above filters
         vcf_out.write_record(record)
         kept_count += 1
@@ -125,6 +142,9 @@ def main():
     print(f'[readcomb] Filtering {args.vcf}')
     if args.min_GQ < 30:
         print('[readcomb] WARNING: min GQ below 30 selected')
+    if not args.purity_filter == -1:
+        print(f'[readcomb] Purity threshold is {args.purity_filter}')
+        print('[readcomb] Set --purity_filter to -1 to disable purity filtering')
     total_count, kept_count = vcfprep(args)
     print('[readcomb] Complete.')
     print(f'[readcomb] {kept_count} of {total_count} records retained.')
